@@ -78,7 +78,7 @@ class Executor(base_executor.BaseExecutor):
         schema = io_utils.SchemaReader().read(schema_path)
         absl.logging.info('schema: {}'.format(schema))
 
-        sklearn_pipeline = dill.loads(exec_properties['preprocessor_pickle'])
+        sklearn_pipeline = dill.loads(exec_properties['preprocessor_pickle']).encode('utf-8')
 
         # Load in the specified module file
         # try:
